relabel_nested_fields

Function relabel_nested_fields 

fn relabel_nested_fields(
    data: ArrayData,
    target: &DataType,
) -> Result<ArrayData>
Rebuilds data with the type target, which must match it position by position apart from nested field names and metadata. Unlike a cast, children are never matched by name.